WorkOsAuthProvider

Struct WorkOsAuthProvider 

pub struct WorkOsAuthProvider { /* private fields */ }
WorkOS AuthKit integration implementing AuthProvider for MCP servers.

This provider makes your MCP server compatible with clients that expect standard OAuth2 authorization server and protected resource discovery endpoints when using WorkOS AuthKit as the identity provider.

Implementations

Source

impl WorkOsAuthProvider

pub fn new(options: WorkOSAuthOptions<'_>) -> Result<Self, McpSdkError>

Creates a new WorkOsAuthProvider instance.

This performs:

  • Validation and parsing of URLs
  • Construction of OAuth2 metadata documents
  • Setup of token verification using JWKs and UserInfo endpoint

/// # Example

use rust_mcp_extra::auth_provider::work_os::{WorkOSAuthOptions, WorkOsAuthProvider};

let auth_provider = WorkOsAuthProvider::new(WorkOSAuthOptions {
   authkit_domain: "https://your-app.authkit.app".to_string(),
   mcp_server_url: "http://localhost:3000/mcp".to_string(),
})?;