pub struct WorkOsAuthProvider { /* private fields */ }Expand description
WorkOS AuthKit integration implementing AuthProvider for MCP servers.
This provider makes your MCP server compatible with clients that expect standard OAuth2 authorization server and protected resource discovery endpoints when using WorkOS AuthKit as the identity provider.
Implementations
Sourceimpl WorkOsAuthProvider
impl WorkOsAuthProvider
Sourcepub fn new(options: WorkOSAuthOptions<'_>) -> Result<Self, McpSdkError>
pub fn new(options: WorkOSAuthOptions<'_>) -> Result<Self, McpSdkError>
Creates a new WorkOsAuthProvider instance.
This performs:
- Validation and parsing of URLs
- Construction of OAuth2 metadata documents
- Setup of token verification using JWKs and UserInfo endpoint
/// # Example
ⓘ
use rust_mcp_extra::auth_provider::work_os::{WorkOSAuthOptions, WorkOsAuthProvider};
let auth_provider = WorkOsAuthProvider::new(WorkOSAuthOptions {
authkit_domain: "https://your-app.authkit.app".to_string(),
mcp_server_url: "http://localhost:3000/mcp".to_string(),
})?;Trait Implementations
Sourceimpl AuthProvider for WorkOsAuthProvider
impl AuthProvider for WorkOsAuthProvider
Sourcefn auth_endpoints(&self) -> Option<&HashMap<String, OauthEndpoint>>
fn auth_endpoints(&self) -> Option<&HashMap<String, OauthEndpoint>>
Returns the map of supported OAuth discovery endpoints.
Sourcefn handle_request<'life0, 'life1, 'async_trait>(
&'life0 self,
request: Request<&'life1 str>,
state: Arc<McpAppState>,
) -> Pin<Box<dyn Future<Output = Result<Response<GenericBody>, TransportServerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn handle_request<'life0, 'life1, 'async_trait>(
&'life0 self,
request: Request<&'life1 str>,
state: Arc<McpAppState>,
) -> Pin<Box<dyn Future<Output = Result<Response<GenericBody>, TransportServerError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Handles incoming requests to OAuth metadata endpoints.
Sourcefn verify_token<'life0, 'async_trait>(
&'life0 self,
access_token: String,
) -> Pin<Box<dyn Future<Output = Result<AuthInfo, AuthenticationError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn verify_token<'life0, 'async_trait>(
&'life0 self,
access_token: String,
) -> Pin<Box<dyn Future<Output = Result<AuthInfo, AuthenticationError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Verifies an access token using JWKs and optional UserInfo validation.
Returns authenticated AuthInfo on success.
Sourcefn protected_resource_metadata_url(&self) -> Option<&str>
fn protected_resource_metadata_url(&self) -> Option<&str>
Returns the full URL to the protected resource metadata document.
Sourcefn required_scopes(&self) -> Option<&Vec<String>>
fn required_scopes(&self) -> Option<&Vec<String>>
Returns an optional list of scopes required to access this resource.
If this function returns
Some(scopes), the authenticated user’s token
must include all of the listed scopes.
If any are missing, the request will be rejected with a 403 Forbidden response.Sourcefn endpoint_type(&self, request: &Request<&str>) -> Option<&OauthEndpoint>
fn endpoint_type(&self, request: &Request<&str>) -> Option<&OauthEndpoint>
Returns the
OauthEndpoint associated with the given request path. Read morefn validate_allowed_methods( &self, endpoint: &OauthEndpoint, method: &Method, ) -> Option<Response<BoxBody<Bytes, TransportServerError>>>